==> tccli-3.0.942.1.tar.gz: tccli-3.0.942.1/tccli/examples/omics/v20221128/DescribeRuns.md <==
**Example 1: 查询任务列表**

查询任务列表。

Input: 

```
tccli omics DescribeRuns --cli-unfold-argument  \
    --ProjectId prj-peaceful-pink-bird-631828 \
    --Limit 2 \
    --Offset 0
```

Output: 
```
{
    "Response": {
        "RequestId": "52ca755d-be35-426a-bd2d-c8c7cf723240",
        "Runs": [
            {
                "ApplicationId": "app-sweet-cerulean-frog-569111",
                "CreateTime": "2023-03-15T20:52:56+08:00",
                "EnvironmentId": "env-05d0g0w2",
                "ErrorMessage": "",
                "ExecutionTime": {
                    "EndTime": "2023-03-15T20:53:23+08:00",
                    "StartTime": "2023-03-15T20:53:13+08:00",
                    "SubmitTime": "2023-03-15T20:53:11+08:00"
                },
                "Input": "omics/2721644692/project/prj-peaceful-pink-bird-631828/run-group/run-ashamed-turquoise-rooster-131773/run/5a66a302-193b-4977-8a43-b4e2e5abd74c/input.json",
                "Option": {
                    "FailureMode": "NoNewCalls",
                    "UseCallCache": true,
                    "UseErrorOnHold": true
                },
                "ProjectId": "prj-peaceful-pink-bird-631828",
                "RunGroupId": "run-ashamed-turquoise-rooster-131773",
                "RunUuid": "5a66a302-193b-4977-8a43-b4e2e5abd74c",
                "Status": "SUCCESS",
                "TableId": "",
                "TableRowUuid": "",
                "UpdateTime": "2023-03-15T20:53:51+08:00",
                "UserDefinedId": ""
            },
            {
                "ApplicationId": "app-sweet-cerulean-frog-569111",
                "CreateTime": "2023-03-15T20:21:34+08:00",
                "EnvironmentId": "env-05d0g0w2",
                "ErrorMessage": "",
                "ExecutionTime": {
                    "EndTime": "2023-03-15T20:22:01+08:00",
                    "StartTime": "2023-03-15T20:21:48+08:00",
                    "SubmitTime": "2023-03-15T20:21:48+08:00"
                },
                "Input": "omics/2721644692/project/prj-peaceful-pink-bird-631828/run-group/run-hilarious-aqua-herring-857343/run/90fae4b6-c891-473d-9e2e-ddbaf367a5bb/input.json",
                "Option": {
                    "FailureMode": "NoNewCalls",
                    "UseCallCache": true,
                    "UseErrorOnHold": false
                },
                "ProjectId": "prj-peaceful-pink-bird-631828",
                "RunGroupId": "run-hilarious-aqua-herring-857343",
                "RunUuid": "90fae4b6-c891-473d-9e2e-ddbaf367a5bb",
                "Status": "SUCCESS",
                "TableId": "",
                "TableRowUuid": "",
                "UpdateTime": "2023-03-15T20:22:28+08:00",
                "UserDefinedId": ""
            }
        ],
        "TotalCount": 3661
    }
}
```

==> tccli-3.0.1063.1.tar.gz: tccli-3.0.1063.1/tccli/examples/omics/v20221128/DescribeRuns.md <==
**Example 1: 查询任务列表**

查询任务列表。

Input: 

```
tccli omics DescribeRuns --cli-unfold-argument  \
    --ProjectId prj-peaceful-pink-bird-631828 \
    --Limit 2 \
    --Offset 0
```

Output: 
```
{
    "Response": {
        "RequestId": "52ca755d-be35-426a-bd2d-c8c7cf723240",
        "Runs": [
            {
                "ApplicationId": "app-sweet-cerulean-frog-569111",
                "CreateTime": "2023-03-15T20:52:56+08:00",
                "EnvironmentId": "env-05d0g0w2",
                "ErrorMessage": "",
                "ExecutionTime": {
                    "EndTime": "2023-03-15T20:53:23+08:00",
                    "StartTime": "2023-03-15T20:53:13+08:00",
                    "SubmitTime": "2023-03-15T20:53:11+08:00"
                },
                "Input": "omics/2721644692/project/prj-peaceful-pink-bird-631828/run-group/run-ashamed-turquoise-rooster-131773/run/5a66a302-193b-4977-8a43-b4e2e5abd74c/input.json",
                "Option": {
                    "FailureMode": "NoNewCalls",
                    "UseCallCache": true,
                    "UseErrorOnHold": true,
                    "UseRelativeOutputPaths": true,
                    "FinalWorkflowOutputsDir": "cos://bucket-10000/output"
                },
                "ProjectId": "prj-peaceful-pink-bird-631828",
                "RunGroupId": "run-ashamed-turquoise-rooster-131773",
                "RunUuid": "5a66a302-193b-4977-8a43-b4e2e5abd74c",
                "Status": "SUCCESS",
                "TableId": "",
                "TableRowUuid": "",
                "UpdateTime": "2023-03-15T20:53:51+08:00",
                "UserDefinedId": ""
            },
            {
                "ApplicationId": "app-sweet-cerulean-frog-569111",
                "CreateTime": "2023-03-15T20:21:34+08:00",
                "EnvironmentId": "env-05d0g0w2",
                "ErrorMessage": "",
                "ExecutionTime": {
                    "EndTime": "2023-03-15T20:22:01+08:00",
                    "StartTime": "2023-03-15T20:21:48+08:00",
                    "SubmitTime": "2023-03-15T20:21:48+08:00"
                },
                "Input": "omics/2721644692/project/prj-peaceful-pink-bird-631828/run-group/run-hilarious-aqua-herring-857343/run/90fae4b6-c891-473d-9e2e-ddbaf367a5bb/input.json",
                "Option": {
                    "FailureMode": "NoNewCalls",
                    "UseCallCache": true,
                    "UseErrorOnHold": false,
                    "UseRelativeOutputPaths": true,
                    "FinalWorkflowOutputsDir": "cos://bucket-10000/output"
                },
                "ProjectId": "prj-peaceful-pink-bird-631828",
                "RunGroupId": "run-hilarious-aqua-herring-857343",
                "RunUuid": "90fae4b6-c891-473d-9e2e-ddbaf367a5bb",
                "Status": "SUCCESS",
                "TableId": "",
                "TableRowUuid": "",
                "UpdateTime": "2023-03-15T20:22:28+08:00",
                "UserDefinedId": ""
            }
        ],
        "TotalCount": 3661
    }
}
```
